@@ -251,6 +251,7 @@ class Shap:
         num_cut = len(self.feature_index) - max_display + 1
         # feature_names[show_features_index[-1]] = f"Sum of {num_cut} other features"
         show_values = values[show_features_index]
+        if len(show_values.shape) > 1: show_values = show_values[:, 0]
         show_features = feature_names[show_features_index].tolist()
         show_features[-1] = f"Sum of {num_cut} other features"
         y_pos = np.arange(max_display, 0, -1)
@@ -312,6 +313,8 @@ class Shap:
         
         ax.set_yticks(list(y_pos))
         ax.set_yticklabels(y_ticklabels.tolist(), fontsize=13)
+        
+        return fig, ax
 
 if __name__ == "__main__":
     from sklearn.datasets import load_boston, load_breast_cancer
